gg_version library
Classes
- AddVersionTag
- Provides "ggGit has-version-tag dir" command
- AllVersions
- Provides "ggGit has-consistent-version dir" command
- ConsistentVersion
- Provides "ggGit has-consistent-version dir" command
- FromChangelog
- Provides "ggGit current-version-tag dir" command
- FromGit
- Provides "ggGit current-version-tag dir" command
- FromPubspec
- Provides "ggGit current-version-tag dir" command
- GgVersion
- The command line interface for GgVersion
- IncreaseBuild
- Increase the build number in the pubspec.yaml file.
- IsVersioned
- Provides "ggGit has-consistent-version dir" command
- MockAddVersionTag
- Mock class for AddVersionTag
- MockAllVersions
- Mock class for AllVersions
- MockConsistentVersion
- Mock class for ConsistentVersion
- MockFromChangelog
- Mock class for FromChangelog
- MockFromGit
- Mock class for FromGit
- MockFromPubspec
- Mock class for FromPubspec
- MockIsVersioned
- Mock class for IsVersioned
- MockWriteVersionFile
- Mock class for WriteVersionFile
- VersionFileSpec
- Describes where a package's generated version file and its mirror test live, and renders their contents.
- WriteVersionFile
- Writes the package version into a generated source file.
Enums
- VersionType
- The type of versions we can have
Constants
- ggVersionVersion → const String
-
The version of the
gg_versionpackage. - versionFileLicenseHeader → const String
- The license header every generated Dart file starts with.
- versionFileMarker → const String
-
Marks a file as generated by
gg version write-version-file.
Functions
-
versionFileIdentifier(
String slug) → String -
Returns the name of the generated constant for
slug. -
versionFileSlug(
String packageName) → String - Converts a package name into the slug used for file names.
-
versionTypeToString(
VersionType type) → String - Converts a versionType to string